==> varbase_auth-9.0.10.tar.gz: varbase_auth/README.md <==
# Varbase Social Single Sign-On
---

This is a [Varbase](https://www.drupal.org/project/varbase) Feature.

Adds single sign-on using existing information from a social networking service. Such as Facebook, Twitter, LinkedIn, or Google.

Built using Social API.
 [Social API](https://www.drupal.org/project/social_api).

Now you can install Varbase Social Single Sign-On with any Drupal 9+ site.
 Even if installed with the Minimal or Standard profile.

However, using it with Varbase distro gives you way much more cool stuff!

### Varbase Auth login
[![](https://www.drupal.org/files/issues/2019-02-21/Log-in--varbase_auth--dev-varbase6c-2.png)](https://www.drupal.org/project/varbase_auth)

### We could enable it at the Extra Components installation step of Varbase.
[![](https://www.drupal.org//files/issues/varbase_auth-installer.png)](https://www.drupal.org/project/varbase_auth)


## Requirements:

* [Social API](https://www.drupal.org/project/social_api).
* [Social Auth](https://www.drupal.org/project/social_auth).
* [Social Auth Google](https://www.drupal.org/project/social_auth_google).
* [Social Auth Facebook](https://www.drupal.org/project/social_auth_facebook).
* [Social Auth Twitter](https://www.drupal.org/project/social_auth_twitter).
* [Social Auth Linkedin](https://www.drupal.org/project/social_auth_linkedin).

This module is best used with [Varbase](https://www.drupal.org/project/varbase)
 distribution.

Join Our Slack Team for Feedback and Support
Join now: http://slack.varbase.vardot.com

This module is sponsored and developed by
 [Vardot](https://www.drupal.org/vardot).

==> varbase_auth-9.1.0.tar.gz: varbase_auth/README.md <==
# Varbase Social Single Sign-On
---

This is a [Varbase](https://www.drupal.org/project/varbase) Feature.

Adds single sign-on using existing information from a social networking service. Such as Facebook, Twitter, LinkedIn, or Google.

Built using Social API.
 [Social API](https://www.drupal.org/project/social_api).

Now you can install Varbase Social Single Sign-On with any Drupal 8 site.
 Even if installed with the Minimal or Standard profile.

However, using it with Varbase distro gives you way much more cool stuff!

### Varbase Auth login
[![](https://www.drupal.org/files/issues/2019-02-21/Log-in--varbase_auth--dev-varbase6c-2.png)](https://www.drupal.org/project/varbase_auth)

### We could enable it at the Extra Components installation step of Varbase.
[![](https://www.drupal.org//files/issues/varbase_auth-installer.png)](https://www.drupal.org/project/varbase_auth)


## Requirements:

* [Social API](https://www.drupal.org/project/social_api).
* [Social Auth](https://www.drupal.org/project/social_auth).
* [Social Auth Google](https://www.drupal.org/project/social_auth_google).
* [Social Auth Facebook](https://www.drupal.org/project/social_auth_facebook).
* [Social Auth Twitter](https://www.drupal.org/project/social_auth_twitter).
* [Social Auth Linkedin](https://www.drupal.org/project/social_auth_linkedin).

This module is best used with [Varbase](https://www.drupal.org/project/varbase)
 distribution.

Join Our Slack Team for Feedback and Support
Join now: http://slack.varbase.vardot.com

This module is sponsored and developed by
 [Vardot](https://www.drupal.org/vardot).
